@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 
 use 5.008002;
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 use Carp ();
 use File::Basename;
@@ -318,6 +318,9 @@ sub install {
 
         # build
         my @make = qw(make);
+        if ($ENV{PERL_BUILD_COMPILE_OPTIONS}) {
+            push @make, $ENV{PERL_BUILD_COMPILE_OPTIONS};
+        }
         if ($jobs) {
             push @make, '-j', $jobs;
         }
